locals {
  API_GATEWAY_LOG_GROUP = "API-Gateway-Execution-Logs_${split("-", aws_api_gateway_stage.main.id)[1]}/${aws_api_gateway_stage.main.stage_name}"
}

output "log_groupe_name" {
  value = local.API_GATEWAY_LOG_GROUP
}

resource "aws_lambda_function" "logs" {
  filename                       = data.archive_file.lambda_logs_file.output_path
  function_name                  = "${local.prefix}-logs-apigw"
  role                           = aws_iam_role.iam_for_lambda_logs.arn
  handler                        = "apigw_metrics.handler"
  timeout                        = 10
  source_code_hash               = data.archive_file.lambda_logs_file.output_base64sha256
  runtime                        = "nodejs12.x"
  reserved_concurrent_executions = 2
  layers = [
    "arn:aws:lambda:eu-west-1:580247275435:layer:LambdaInsightsExtension:14"
  ]
  environment {
    variables = {
      API_GATEWAY_LOG_GROUP = local.API_GATEWAY_LOG_GROUP
    }
  }

  tags = local.common_tags
}

resource "aws_lambda_function" "logs_events" {
  filename                       = data.archive_file.lambda_logs_event_file.output_path
  function_name                  = "${local.prefix}-logs-events-apigw"
  role                           = aws_iam_role.iam_for_lambda_logs.arn
  handler                        = "apigw_metrics_live.handler"
  timeout                        = 10
  source_code_hash               = data.archive_file.lambda_logs_event_file.output_base64sha256
  runtime                        = "nodejs12.x"
  reserved_concurrent_executions = 200
  layers = [
    "arn:aws:lambda:eu-west-1:580247275435:layer:LambdaInsightsExtension:14"
  ]
  environment {
    variables = {
      API_GATEWAY_LOG_GROUP = local.API_GATEWAY_LOG_GROUP
    }
  }

  tags = local.common_tags
}

data "archive_file" "lambda_logs_file" {
  type        = "zip"
  output_path = "${local.lambda_loc}/zip/apigw_metrics.zip"
  source_file = "${local.lambda_loc}/apigw_metrics/apigw_metrics.js"
}

data "archive_file" "lambda_logs_event_file" {
  type        = "zip"
  output_path = "${local.lambda_loc}/zip/apigw_metrics_events.zip"
  source_file = "${local.lambda_loc}/apigw_metrics/apigw_metrics_live.js"
}

resource "aws_iam_role" "iam_for_lambda_logs" {
  name               = "${local.prefix}-lambda-admin-cloudwatch-logs"
  assume_role_policy = file("./templates/lambda/assume-role-policy.json")
}

resource "aws_iam_role_policy_attachment" "lambda_logs_FA" {
  role       = aws_iam_role.iam_for_lambda_logs.name
  policy_arn = "arn:aws:iam::aws:policy/CloudWatchLogsFullAccess"
}

resource "aws_iam_role_policy_attachment" "lambda_cloudwatch_FA" {
  role       = aws_iam_role.iam_for_lambda_logs.name
  policy_arn = "arn:aws:iam::aws:policy/CloudWatchFullAccess"
}
