const AWS = require('aws-sdk')
const CW = new AWS.CloudWatch()
const CWL = new AWS.CloudWatchLogs()
const API_GATEWAY_LOG_GROUP = process.env.API_GATEWAY_LOG_GROUP
const now = Date.now()/1000
const period = 30 * 60 // seconds
exports.handler = async function(event){

    const params = {
        logGroupName: API_GATEWAY_LOG_GROUP,
        startTime: now - period,
        endTime: now,
        queryString: `fields @timestamp, @message
        | parse @message \"(*) *\" as reqId, lMessage
        | filter lMessage like /Method completed with status:/
        | parse lMessage \"Method completed with status: *\" as status
        | display @timestamp, reqId, status`
    };
      
    // 1. Start the query. When we start a query, this returns a queryId for us to use on our next step.
    const data = await CWL.startQuery(params).promise();
    const { queryId } = data;
    console.debug('query id', queryId);

    while (true) {
    
    // 2. Send Insight query to CloudwatchLogs
    const insightData = await CWL.getQueryResults({ queryId }).promise();
    console.log(JSON.stringify(insightData,null,4))
    // 3. Check if it is available    
    if (Array.isArray(insightData.results) && insightData.status === 'Complete') {
        const insightResult = insightData.results;
        
        // Change this line to publish to SNS or send to Slack
        console.log(JSON.stringify(insightResult, null, 4))
        break;
    }
    
    // 4. Otherwise, Wait for 100 ms for insight api result
    await new Promise((resolve, reject) => setTimeout(resolve, 100));
    } 

    return 'ok';
}